import { View, Text, Input } from "@tarojs/components"
import Taro, { useDidShow } from "@tarojs/taro"
import { Button, Form, FormItem, Icon } from "@antmjs/vantui";

import { useEffect, useState } from "react";
import { useModel } from "../../store";
import { getPhoneuser, setUserInfo } from "../../services/user";
import './style.less'

let form = null

export default (props) => {
  const { deptName, person, setPerson, sessionKey } = useModel('userData')
  const onSubmit = (e) => {
    form.validateFields((errorMessage, fieldValues) => {
      if (errorMessage && errorMessage.length) {
        return console.info('errorMessage', errorMessage)
      } else {
        setUserInfo({ ...fieldValues, person: person?.personId, deptCode: deptName?.id }).then((e) => {
          setPerson(e);
          Taro.showToast({
            title: '保存成功',
            icon: 'none',
            duration: 2000
          }).then(() => {
            Taro.redirectTo({
              url: '/pages/index/index'
            })
          })

        })

      }
    })
  }
  const getPhone = (e) => {
    const { errMsg, ...data } = e.detail || {}
    getPhoneuser({ ...data, sessionKey: sessionKey }).then((res) => {
      form.setFieldsValue('phone', res?.phoneNumber)
    })

  }

  const goDepartmen = () => {
    Taro.navigateTo({
      url: '/pages/DepartmentSelection/index'
    })

  }

  useEffect(() => {
    if (person) {
      form.setFields(person)
    }
    if (deptName) {
      form.setFieldsValue('deptName', deptName?.name)
    }
  }, [deptName, person])



  return (
    <View className='page-index'>
      <Form
        ref={(el) => (form = el)}
        onFinish={(e) => onSubmit(e)}
      >
        <FormItem
          label='用户名'
          name='personName'
          required
          trigger='onInput'
          validateTrigger='onBlur'
          valueFormat={(e) => e.detail.value}
        >
          <Input placeholder='请输入用户名' />
        </FormItem>
        <FormItem
          label='手机号'
          name='phone'
          trigger='onInput'
          required
          validateTrigger='onBlur'
          valueFormat={(e) => e.detail.value}
          renderRight={<Button
            plain
            hairline
            size='small'
            type='info'
            required
            openType='getPhoneNumber'
            onGetPhoneNumber={getPhone}
          >
            授权手机
          </Button>}
        >
          <Input placeholder='请输入手机号' maxlength={11} disabled />


        </FormItem>

        <FormItem
          label='身份证'
          name='idNo'
          required
          trigger='onInput'
          validateTrigger='onBlur'
          valueFormat={(e) => e.detail.value}
        >
          <Input placeholder='请输入身份证号' type='number' maxlength={18} />
        </FormItem>

        <FormItem
          label='科室'
          name='deptName'
          trigger='onInput'
          required
          validateTrigger='onBlur'
          valueFormat={(e) => e.detail.value}
        >
          <Input placeholder='请选择科室' onClick={goDepartmen} disabled />
        </FormItem>
        <View className='buttom-box'>
          <Button
            type='info'
            size='normal'
            formType='submit'
            className='buttom-box-buttonSubmit'
          >
            提交
          </Button>
        </View>

      </Form>
    </View>
  )
}
